==> haskell-sandi-0.5-438-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sandi
version:              0.5
visibility:           public
id:                   sandi-0.5-84FPUzoqrVFHNb2KLRRLVO
key:                  sandi-0.5-84FPUzoqrVFHNb2KLRRLVO
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
synopsis:             Data encoding library
description:          Reasonably fast data encoding library.
category:             Codec, Conduit
abi:                  8fe84a6d266d56d2a9335c3abc7a6785
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc

hidden-modules:       Paths_sandi Data.Conduit.Codec.Util
import-dirs:          /usr/lib/ghc-9.2.8/site-local/sandi-0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandi
hs-libraries:         HSsandi-0.5-84FPUzoqrVFHNb2KLRRLVO
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.5-m4mJvLp39j4uQ7WG40JEh exceptions-0.10.4

haddock-interfaces:   /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html:         /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandi-0.5-450-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sandi
version:              0.5
visibility:           public
id:                   sandi-0.5-J0aVjc0Yk4lBYm14s0Iusq
key:                  sandi-0.5-J0aVjc0Yk4lBYm14s0Iusq
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
synopsis:             Data encoding library
description:          Reasonably fast data encoding library.
category:             Codec, Conduit
abi:                  799d8d8ee56118d8983d9d8de197e289
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc

hidden-modules:       Paths_sandi Data.Conduit.Codec.Util
import-dirs:          /usr/lib/ghc-9.2.8/site-local/sandi-0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandi
hs-libraries:         HSsandi-0.5-J0aVjc0Yk4lBYm14s0Iusq
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x exceptions-0.10.4

haddock-interfaces:   /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html:         /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
